@@ -105,23 +105,29 @@ class App:
         await self.middleware(scope, receive, send)
 
     async def handle_request(self, request):
-        handler, kwargs, methods = self.find_handler(request_path=request.url.path)
-        
-        assert request.method.lower() in methods, f"Method {request.method.lower()} not allowed"
-
         try:
-            if handler is not None:
+            handler, kwargs, methods = self.find_handler(request_path=request.url.path)
+            
+            assert request.method.lower() in methods, f"Method {request.method.lower()} not allowed"
 
-                if inspect.iscoroutinefunction(handler):
-                    response = await handler(request, **kwargs)
+            try:
+                if handler is not None:
 
+                    if inspect.iscoroutinefunction(handler):
+                        response = await handler(request, **kwargs)
+
+                    else:
+                        response = handler(request, **kwargs)
                 else:
-                    response = handler(request, **kwargs)
-            else:
-                return self.default_response(request)
+                    return self.default_response(request)
 
-        except Exception as e:
+            except Exception as e:
+                error = traceback.format_exc()
+                print(error)
+                response = self.exception_handler.handle_error(request, error)
+        except:
             error = traceback.format_exc()
+            print(error)
             response = self.exception_handler.handle_error(request, error)
 
         return response
@@ -137,7 +143,7 @@ class App:
             if parse_result is not None:
                 return handler, parse_result.named, methods
 
-        return None, None
+        return None, None, None
 
     def route(self, path: str, methods=["GET", "POST", "HEAD", "PUT", "DELETE", "CONNECT", "OPTIONS", "TRACE", "PATCH"]):
 
